pub struct TopologicalSortConfig { /* private fields */ }Expand description
Configuration for how we do topological sorts.
We remove Debug because closures cannot derive Debug easily.
Implementations
Sourceimpl TopologicalSortConfig
impl TopologicalSortConfig
Sourcepub fn reverse_order(&self) -> &bool
pub fn reverse_order(&self) -> &bool
If true, reverse the final order (or reverse the layer vector).
Sourcepub fn filter_fn(&self) -> &Option<Arc<dyn Fn(&str) -> bool + Send + Sync>>
pub fn filter_fn(&self) -> &Option<Arc<dyn Fn(&str) -> bool + Send + Sync>>
Optional filter: skip or remove crates that do not satisfy this predicate.
Sourcepub fn remove_unwanted_from_graph(&self) -> &bool
pub fn remove_unwanted_from_graph(&self) -> &bool
If true, we remove crates that fail the filter from the graph entirely;
if false, we keep them in the graph but omit them from final output.
Sourcepub fn layering_enabled(&self) -> &bool
pub fn layering_enabled(&self) -> &bool
If true, we do layered sorting; if false, we do flat topological sorting.
Sourceimpl TopologicalSortConfig
impl TopologicalSortConfig
Sourcepub fn set_reverse_order(&mut self, val: bool) -> &mut TopologicalSortConfig
pub fn set_reverse_order(&mut self, val: bool) -> &mut TopologicalSortConfig
If true, reverse the final order (or reverse the layer vector).
Sourcepub fn set_filter_fn(
&mut self,
val: Option<Arc<dyn Fn(&str) -> bool + Send + Sync>>,
) -> &mut TopologicalSortConfig
pub fn set_filter_fn( &mut self, val: Option<Arc<dyn Fn(&str) -> bool + Send + Sync>>, ) -> &mut TopologicalSortConfig
Optional filter: skip or remove crates that do not satisfy this predicate.
Sourcepub fn set_remove_unwanted_from_graph(
&mut self,
val: bool,
) -> &mut TopologicalSortConfig
pub fn set_remove_unwanted_from_graph( &mut self, val: bool, ) -> &mut TopologicalSortConfig
If true, we remove crates that fail the filter from the graph entirely;
if false, we keep them in the graph but omit them from final output.
Sourcepub fn set_layering_enabled(&mut self, val: bool) -> &mut TopologicalSortConfig
pub fn set_layering_enabled(&mut self, val: bool) -> &mut TopologicalSortConfig
If true, we do layered sorting; if false, we do flat topological sorting.
Sourcepub fn set_weighting_fn(
&mut self,
val: Option<Arc<dyn Fn(&str) -> u32 + Send + Sync>>,
) -> &mut TopologicalSortConfig
pub fn set_weighting_fn( &mut self, val: Option<Arc<dyn Fn(&str) -> u32 + Send + Sync>>, ) -> &mut TopologicalSortConfig
If present, used in layered approach to break ties within a layer.